=======
History
=======

1.0.0 (2020-09-03)
------------------

* First release on PyPI.

1.0.1 (2020-09-07)
------------------

Lots of things have been fixed, including:

* Automation create (CRUD) API
* Update template API
* Update zemfrog release information.
